=======
I2C LCD
=======


.. image:: https://img.shields.io/pypi/v/i2c_lcd.svg
        :target: https://pypi.python.org/pypi/i2c_lcd

.. image:: https://img.shields.io/travis/pwlandoll/i2c_lcd.svg
        :target: https://travis-ci.org/pwlandoll/i2c_lcd

.. image:: https://readthedocs.org/projects/i2c-lcd/badge/?version=latest
        :target: https://i2c-lcd.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/pwlandoll/i2c_lcd/shield.svg
     :target: https://pyup.io/repos/github/pwlandoll/i2c_lcd/
     :alt: Updates


I2C LCD interface in Python made for RPi.


* Free software: GNU General Public License v3
* Documentation: https://i2c-lcd.readthedocs.io.


Features
--------

* Interface with I2C-connected LCD screens, by means of the SMBus, most commonly with Raspberry Pi boards.
* Display text on the screen, given as a string or characters.

Credits
---------

The code in this package is based almost entirely on code by DenisFromHR
(Denis Pleic), taken 2017-3-26 from `GitHub Gists`_.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _GitHub Gists: https://gist.github.com/DenisFromHR/cc863375a6e19dce359d#file-rpi_i2c_driver-py

